﻿// --------------------------------------------------------------------------------------------------------------------- 
// <copyright file="Product.cs" company="Microsoft">
//   Product
// </copyright>
// <summary>
//   Defines the Product type.
// </summary>
// ---------------------------------------------------------------------------------------------------------------------
// ==++==
// 
//   Copyright (c) Microsoft Corporation.  All rights reserved.
// 
// ==--==
namespace FabrikamSports
{
    using System;

    /// <summary>
    /// The Product for the Company.
    /// </summary>
    public class Product
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="Product"/> class.
        /// </summary>
        /// <param name="productName">Name of the product.</param>
        /// <param name="description">The description.</param>
        public Product(string productName, string description)
        {
            this.Name = productName;
            this.Description = description;
            this.ProductId = Guid.NewGuid();
        }

        /// <summary>
        /// Gets the product id.
        /// </summary>
        /// <value>The product id.</value>
        public Guid ProductId
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the name of the product.
        /// </summary>
        /// <value>The name of the product.</value>
        public string Name
        {
            get; private set;
        }

        /// <summary>
        /// Gets the description of the product.
        /// </summary>
        /// <value>The description.</value>
        public string Description { get; private set; }
    }
}
