﻿// --------------------------------------------------------------------------------------------------------------------- 
// <copyright file="Warehouse.cs" company="Microsoft">
//   warehouse
// </copyright>
// <summary>
//   Defines the Warehouse type.
// </summary>
// ---------------------------------------------------------------------------------------------------------------------
// ==++==
// 
//   Copyright (c) Microsoft Corporation.  All rights reserved.
// 
// ==--==
namespace FabrikamSports
{
    using System.Collections.Generic;

    /// <summary>
    /// Warehouse implemenation
    /// </summary>
    public class Warehouse
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="Warehouse"/> class.
        /// </summary>
        public Warehouse()
        {
            // Initialize Products
            this.BasketBalls = new List<Product>
                                   {
                                       new Basketball(),
                                       new Basketball(),
                                       new Basketball()
                                   };

            this.BaseBalls = new List<Product>
                                 {
                                     new Baseball(),
                                     new Baseball(),
                                     new Baseball()
                                 };
        }

        /// <summary>
        /// Gets the basket balls.
        /// </summary>
        /// <value>The basket balls.</value>
        public List<Product> BasketBalls
        {
            get; private set;
        }

        /// <summary>
        /// Gets the base balls.
        /// </summary>
        /// <value>The base balls.</value>
        public List<Product> BaseBalls
        {
            get; private set;
        }

        /// <summary>
        /// Checks the inventory
        /// </summary>
        /// <param name="product">The product.</param>
        /// <param name="quantity">The quantity.</param>
        /// <returns>Returns <see cref="bool"/></returns>
        public virtual bool HasInventory(Product product, int quantity)
        {
            bool hasInventory = false;

            // Check the Inventory
            if (this.GetInventory(product) >= quantity)
            {
                hasInventory = true;
            }

            return hasInventory;
        }

        /// <summary>
        /// Removes item from Inventory
        /// </summary>
        /// <param name="product">The product.</param>
        /// <param name="quantity">The quantity.</param>
        public void Remove(Product product, int quantity)
        {
            switch (product.Name)
            {
                case "Base Ball":
                    this.BaseBalls.Remove(product);
                    break;
                case "Basket Ball":
                    this.BasketBalls.Remove(product);
                    break;
            }
        }

        /// <summary>
        /// Get the inventory
        /// </summary>
        /// <param name="product">The product.</param>
        /// <returns>Returns <see cref="bool"/></returns>
        private int GetInventory(Product product)
        {
            switch (product.Name)
            {
                case "Base Ball":
                    return this.BaseBalls.Count;
                case "Basket Ball":
                    return this.BasketBalls.Count;
            }

            return 0;
        }
    }
}
