﻿using System;
// ==++==
// 
//   Copyright (c) Microsoft Corporation.  All rights reserved.
// 
// ==--==

namespace FabrikamSports.PexModels
{
    using Microsoft.Pex.Framework;
    using Microsoft.Pex.Framework.Choices;
    using System;
    using Microsoft.VisualStudio.TestTools.UnitTesting;

    /// <summary>
    /// Parameterized Model for IWareHouse
    /// </summary>
    public sealed class PWareHouse : IWareHouse
    {
        PexChosenIndexedValue<Product, int> products;

        /// <summary>
        /// Initializes a new instance of the <see cref="PWareHouse"/> class.
        /// </summary>
        public PWareHouse()
        {
            this.products = new PexChosenIndexedValue<Product, int>(this, "Products", quantity => quantity >= 0);
        }

        /// <summary>
        /// Check for Inventory
        /// </summary>
        /// <param name="product">The product.</param>
        /// <param name="quantity">The quantity.</param>
        /// <returns>Returns <see cref="bool"/></returns>
        public bool HasInventory(Product product, int quantity)
        {
            int availableQuantity = this.products.GetItem(product);
            return quantity - availableQuantity > 0;
        }

        /// <summary>
        /// Removes an item from the Invetory
        /// </summary>
        /// <param name="product">The product.</param>
        /// <param name="quantity">The quantity.</param>
        public void Remove(Product product, int quantity)
        {

            if (this.products.GetItem(product) - quantity < 0)
            {
                throw new ArgumentException("No products available.");
            }

            int availableQuantity = this.products.GetItem(product);
            var resultingQuantity = availableQuantity - quantity;
            Assert.IsTrue(resultingQuantity >= 0);
            this.products.SetItem(product, resultingQuantity);
        }
    }
}
