﻿using FabrikamSports;
using System;
// --------------------------------------------------------------------------------------------------------------------- 
// <copyright file="Order.cs" company="Microsoft">
//   Order
// </copyright>
// <summary>
//   Defines the Order type.
// </summary>
// ---------------------------------------------------------------------------------------------------------------------
// ==++==
// 
//   Copyright (c) Microsoft Corporation.  All rights reserved.
// 
// ==--==
namespace FabrikamSports
{
    using System;
    using System.Collections;
    using System.Collections.Generic;

    /// <summary>
    /// Order Class for FabrikamSports
    /// </summary>
    public class Order
    {
        /// <summary>
        /// WareHouse object
        /// </summary>
        private readonly IWareHouse orderWareHouse;

        /// <summary>
        /// repository for the Orders
        /// </summary>
        private readonly IDictionary orderList = new Dictionary<Guid, int>();

        /// <summary>
        /// Initializes a new instance of the <see cref="Order"/> class.
        /// </summary>
        /// <param name="wareHouse">The ware house.</param>
        public Order(IWareHouse wareHouse)
        {
            
            //if (wareHouse == (IWareHouse)null)
            //    throw new ArgumentNullException("wareHouse");
            // Use constructor injection to provide a wareHouse object
            this.orderWareHouse = wareHouse;
        }

        /// <summary>
        /// Checks if the product is available and places the order.
        /// </summary>
        /// <param name="product">The product.</param>
        /// <param name="quantity">The quantity.</param>
        /// <returns>Returns true if product is available</returns>
        public bool Fill(Product product, int quantity)
        {
            if (product == null)
            {
                throw new ArgumentException();
            }

            // Check if WareHouse has any inventory
            if (this.orderWareHouse.HasInventory(product, quantity))
            {
                // Save the order
                this.SaveOrder(product.ProductId, quantity);

                // Subtract the quantity from the product in the warehouse
                this.orderWareHouse.Remove(product, quantity);
                return true;
            }

            return false;
        }

        /// <summary>
        /// Saves the order.
        /// </summary>
        /// <param name="productId">The product id.</param>
        /// <param name="quantity">The quantity.</param>
        private void SaveOrder(Guid productId, int quantity)
        {
            this.orderList.Add(productId, quantity);
        }
    }
}
